@@ -11,11 +11,12 @@ Provides access to a single device on the 1-Wire bus.
 * Author(s): Carter Nelson
 """
 
-__version__ = "2.0.3"
+__version__ = "2.0.4"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_OneWire.git"
 
 try:
     from typing import Optional, Type
+    from circuitpython_typing import ReadableBuffer, WriteableBuffer
     from types import TracebackType
     from adafruit_onewire.bus import OneWireBus, OneWireAddress
 except ImportError:
@@ -44,7 +45,7 @@ class OneWireDevice:
         return False
 
     def readinto(
-        self, buf: bytearray, *, start: int = 0, end: Optional[int] = None
+        self, buf: WriteableBuffer, *, start: int = 0, end: Optional[int] = None
     ) -> None:
         """
         Read into ``buf`` from the device. The number of bytes read will be the
@@ -54,7 +55,7 @@ class OneWireDevice:
         as if ``buf[start:end]``. This will not cause an allocation like
         ``buf[start:end]`` will so it saves memory.
 
-        :param bytearray buf: buffer to write into
+        :param WriteableBuffer buf: Buffer to write into
         :param int start: Index to start writing at
         :param int end: Index to write up to but not include
         """
@@ -64,7 +65,7 @@ class OneWireDevice:
                 raise RuntimeError("CRC error.")
 
     def write(
-        self, buf: bytearray, *, start: int = 0, end: Optional[int] = None
+        self, buf: ReadableBuffer, *, start: int = 0, end: Optional[int] = None
     ) -> None:
         """
         Write the bytes from ``buf`` to the device.
@@ -73,7 +74,7 @@ class OneWireDevice:
         as if ``buffer[start:end]``. This will not cause an allocation like
         ``buffer[start:end]`` will so it saves memory.
 
-        :param bytearray buf: buffer containing the bytes to write
+        :param ReadableBuffer buf: buffer containing the bytes to write
         :param int start: Index to start writing from
         :param int end: Index to read up to but not include
         """
